pub struct FileIndexCache { /* private fields */ }Expand description
A cached file index that can be shared across searches.
Implementations
Sourceimpl FileIndexCache
impl FileIndexCache
pub fn new( search_directory: PathBuf, exclude: impl IntoIterator<Item = String>, respect_gitignore: bool, threads: usize, ) -> Self
Sourcepub async fn get_or_build(&self) -> Result<Arc<FileIndex>>
pub async fn get_or_build(&self) -> Result<Arc<FileIndex>>
Get or build the file index.
Sourcepub fn refresh_background(&self) -> Option<Arc<FileIndex>>
pub fn refresh_background(&self) -> Option<Arc<FileIndex>>
Force refresh the index in the background. Returns the old index immediately while rebuilding happens asynchronously.
Sourcepub fn update_file(&self, path: &str, is_added: bool)
pub fn update_file(&self, path: &str, is_added: bool)
Incrementally update the index when a file change is detected. This is faster than a full rebuild for single file changes.